==> vivotek_2.4.7.tar.gz: www/rc-selector.js <==
var identrc;


function reloadrc() {

			
			location.reload();
	

}


function startapprc() {

	$.ajax({

		url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=start&idx=" + identrc+"&drc="+ getStringNormalDate(new Date()),
		success: function () {

			DevExpress.ui.notify("Application restarted", "success", 600);
			
			setTimeout(reloadrc, 1000);
		}

	});

}

function reloadpage()
{
	location.reload();
}

function set_rcpopup() {

	checkstatus();


	$.ajax({
		dataType: "json",
		url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlconfcamera&camp0=id&comp0=minor&value0=3&maxvalues=2&drc="+ getStringNormalDate(new Date()),
		async: false,
		success: function (data) {

	
			if(data.length < 2)
			{
				$("#popuprc").append("<p>"+DevExpress.localization.formatMessage("Creating database... Please reload")+" </p>");
				
					var poup = $("#popuprc").dxPopup({
						showTitle: true,
						title: DevExpress.localization.formatMessage("Creating database"),
						visible: true,
						maxWidth: 600,
						maxHeight: 250,
						loseOnOutsideClick: true,
							onHidden: function (e) {
							location.reload();
							}
				
						
					});
				return;
			}
		
			if (data[0].value == -1  || data[1].value == "" ) {

				$("#popuprc").append("<div class='dx-field'><div class='dx-field-label'>"+DevExpress.localization.formatMessage("Region:")+"</div><div class='dx-field-value'><div id='regionrc'></div></div></div><div class='dx-field'><div class='dx-field-label'>"+DevExpress.localization.formatMessage("Country")+":</div><div class='dx-field-value'><div id='countryrc'></div></div></div><div class='dx-field'><div class='dx-field-value'><div id='btsaverc'></div></div></div>");

				
				
				var countries;
				var countriesdsrc;
				var regions;

				$.ajax({
					dataType: "json",
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getident",
					async: false,
					success: function (data) {

						identrc = data;
					}
				});

				$.ajax({
					dataType: "json",
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlregion&maxvalues=250",
					async: false,
					success: function (data) {

						regions = data;
					},
					error: function (data)
					{
						setTimeout(reloadpage, 1000);
						return;
					}
				});

				var regiondsrc = new DevExpress.data.DataSource({
						store: regions,
						key: "id",

					});

			 var jqxhr4 = $.ajax({
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=1&camp1=value&value1=3&camp2=computerid&value2=1&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
					async: false
			 });
			 var jqxhr5 = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=2&camp1=value&value1=&camp2=computerid&value2=" + computerid + "&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false
			});
				
				$("#regionrc").dxSelectBox({
					dataSource: regiondsrc,
					valueExpr: "id",
					searchEnabled: true,
					value: 3,
					displayExpr: "description",
					onValueChanged: function (e) {
						var previousValue = e.previousValue;
						var newValue = e.value;

						$.ajax({
							dataType: "json",
							url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlcountry&comp0=equal&camp0=regionid&value0=" + newValue + "&maxvalues=250",
							async: false,
							success: function (data) {

								$("#countryrc").dxTagBox("instance").option("dataSource", data);
								$("#countryrc").dxTagBox("instance").reset();

							}
						});
						var jqxhr = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=2&camp1=value&value1=&camp2=computerid&value2=" + computerid + "&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false,
						success: function (data) {
								DevExpress.ui.notify("Data saved", "success", 600);
							}
						});

						 var jqxhr = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=1&camp1=value&value1=" + newValue + "&camp2=computerid&value2=1&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false,
						success: function (data) {
								DevExpress.ui.notify("Data saved", "success", 600);
							}
						});
			 
				

					}
				});

				$.ajax({
					dataType: "json",
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlcountry&comp0=equal&camp0=regionid&value0=3&maxvalues=250",
					async: false,
					success: function (data) {

						countriesdsrc = new DevExpress.data.DataSource({
								store: data,
								key: "id",

							});
					},
					error: function (data)
					{
						setTimeout(reloadpage, 1000);
						return;
					}
				});

				$("#countryrc").dxTagBox({
					dataSource: countriesdsrc,
					valueExpr: "id",
					searchEnabled: true,
					//value: [101],
					displayExpr: "description",
					onValueChanged: function (e) {
						var previousValue = e.previousValue;
						var newValue = e.value;
						var counts = "";
						$.each(newValue, function (i, item) {
							counts += item + ";";
						});
						counts = counts.substring(0, counts.length - 1);

						
						
						var jqxhr = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=2&camp1=value&value1=" + counts + "&camp2=computerid&value2=" + computerid + "&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false,
						success: function (data) {
								DevExpress.ui.notify("Data saved", "success", 600);
							}
						});
					
							
										

					}
				});

				var poup = $("#popuprc").dxPopup({
						showTitle: true,
						title: DevExpress.localization.formatMessage("Region/country selection"),
						visible: true,
						maxWidth: 600,
						maxHeight: 250,
						loseOnOutsideClick: true,
						onHidden: function (e) {
						
						
						
							$.ajax({
								url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=stop&idx=" + ident,
								success: function () {

									setTimeout(startapprc, 1000);

								}
							});
						},
						onHiding: function (e)
						{
								var countryvar=$("#countryrc").dxTagBox("instance").option("value");
								var regionvar=$("#regionrc").dxSelectBox("instance").option("value");
								
								
							if(countryvar.length == 0  || regionvar == null )
							{
								e.cancel= true;
								DevExpress.ui.notify("Please select a region and countries", "error", 600);
							}							
							
							
						}
						
					});
				$(".dx-toolbar-after").hide();
					//buton
				$("#btsaverc").dxButton({
				type: "success",
				text: DevExpress.localization.formatMessage("Save and close"),
				onClick: function () {
				 $("#popuprc").dxPopup("hide");
				 		$.ajax({
				url:  pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=stop&idx="+ident+"&drc="+ getStringNormalDate(new Date()),
				success: function () {
				
					setTimeout(startapprc, 2000);
					
				
				}
			});
				
				}
				});
					
					
					
					
					
			}
			
		},
		error: function (data)
		{
				
				$("#popuprc").append("<p>"+DevExpress.localization.formatMessage("Creating database... Please reload")+" </p>");
				var poup = $("#popuprc").dxPopup({
						showTitle: true,
						title: "Creating database",
						visible: true,
						maxWidth: 600,
						maxHeight: 250,
						loseOnOutsideClick: true,
							onHidden: function (e) {
							location.reload();
							}
				
						
					});
				return;
		}
	});

}

==> vivotek_3.0.2.0.tar.gz: www/rc-selector.js <==
var identrc;


function reloadrc() {

			
			location.reload();
	

}


function startapprc() {

	$.ajax({

		url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=start&idx=" + identrc+"&drc="+ getStringNormalDate(new Date()),
		success: function () {

			DevExpress.ui.notify("Application restarted", "success", 600);
			
			setTimeout(reloadrc, 1000);
		}

	});

}

function reloadpage()
{
	location.reload();
}

function set_rcpopup() {

	//checkstatus();


	$.ajax({
		dataType: "json",
		url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlconfcamera&camp0=id&comp0=between&value0=0;3&maxvalues=100&drc="+ getStringNormalDate(new Date()),
		async: false,
		success: function (data) {

	
			if(data.length < 2)
			{
				//$("#popuprc").append("<p>"+DevExpress.localization.formatMessage("Please wait...")+" </p>");
				//	var poup = $("#popuprc").dxPopup({
				//		showTitle: true,
				//		title: DevExpress.localization.formatMessage("Loading..."),
				//		visible: true,
				//		maxWidth: 600,
				//		maxHeight: 250,
				//		loseOnOutsideClick: true,
				//			onHidden: function (e) {
				//			location.reload();
				//			}		
				//	});
				setTimeout(reloadpage, 5000);
				return;
			}
		
			if (data[0].value == -1  || data[1].value == "" ) {

				$("#popuprc").append("<div class='dx-field'><div class='dx-field-label'>"+DevExpress.localization.formatMessage("Region:")+"</div><div class='dx-field-value'><div id='regionrc'></div></div></div><div class='dx-field'><div class='dx-field-label'>"+DevExpress.localization.formatMessage("Country")+":</div><div class='dx-field-value'><div id='countryrc'></div></div></div><div class='dx-field'><div class='dx-field-value'><div id='btsaverc'></div></div></div>");

				
				
				var countries;
				var countriesdsrc;
				var regions;

				$.ajax({
					dataType: "json",
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getident",
					async: false,
					success: function (data) {

						identrc = data;
					}
				});

				$.ajax({
					dataType: "json",
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlregion&maxvalues=250",
					async: false,
					success: function (data) {

						regions = data;
					},
					error: function (data)
					{
						setTimeout(reloadpage, 1000);
						return;
					}
				});

				var regiondsrc = new DevExpress.data.DataSource({
						store: regions,
						key: "id",

					});

			 var jqxhr4 = $.ajax({
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=1&camp1=value&value1=3&camp2=computerid&value2=1&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
					async: false
			 });
			 var jqxhr5 = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=2&camp1=value&value1=&camp2=computerid&value2=" + computerid + "&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false
			});
				
				$("#regionrc").dxSelectBox({
					dataSource: regiondsrc,
					valueExpr: "id",
					searchEnabled: true,
					value: 3,
					displayExpr: "description",
					onValueChanged: function (e) {
						var previousValue = e.previousValue;
						var newValue = e.value;

						$.ajax({
							dataType: "json",
							url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlcountry&comp0=equal&camp0=regionid&value0=" + newValue + "&maxvalues=250",
							async: false,
							success: function (data) {

								$("#countryrc").dxTagBox("instance").option("dataSource", data);
								$("#countryrc").dxTagBox("instance").reset();

							}
						});
						var jqxhr = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=2&camp1=value&value1=&camp2=computerid&value2=" + computerid + "&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false,
						success: function (data) {
								DevExpress.ui.notify("Data saved", "success", 600);
							}
						});

						 var jqxhr = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=1&camp1=value&value1=" + newValue + "&camp2=computerid&value2=1&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false,
						success: function (data) {
								DevExpress.ui.notify("Data saved", "success", 600);
							}
						});
			 
				

					}
				});

				$.ajax({
					dataType: "json",
					url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=select&table=nlcountry&comp0=equal&camp0=regionid&value0=3&maxvalues=250",
					async: false,
					success: function (data) {

						countriesdsrc = new DevExpress.data.DataSource({
								store: data,
								key: "id",

							});
					},
					error: function (data)
					{
						setTimeout(reloadpage, 1000);
						return;
					}
				});

				$("#countryrc").dxTagBox({
					dataSource: countriesdsrc,
					valueExpr: "id",
					searchEnabled: true,
					//value: [101],
					displayExpr: "description",
					onValueChanged: function (e) {
						var previousValue = e.previousValue;
						var newValue = e.value;
						var counts = "";
						$.each(newValue, function (i, item) {
							counts += item + ";";
						});
						counts = counts.substring(0, counts.length - 1);

						
						
						var jqxhr = $.ajax({
						url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=update&table=nlconfcamera&camp0=id&value0=2&camp1=value&value1=" + counts + "&camp2=computerid&value2=" + computerid + "&camp3=cameraid&value3=-1"+"&d="+ getStringNormalDate(new Date()),
						async: false,
						success: function (data) {
								DevExpress.ui.notify("Data saved", "success", 600);
							}
						});
					
							
										

					}
				});

				var poup = $("#popuprc").dxPopup({
						showTitle: true,
						title: DevExpress.localization.formatMessage("Region/country selection"),
						visible: true,
						maxWidth: 600,
						maxHeight: 250,
						loseOnOutsideClick: true,
						onHidden: function (e) {
							// se envia restart por segunda vez					
							//restartapp();
						},
						onHiding: function (e)
						{
								var countryvar=$("#countryrc").dxTagBox("instance").option("value");
								var regionvar=$("#regionrc").dxSelectBox("instance").option("value");
								
								
							if(countryvar.length == 0  || regionvar == null )
							{
								e.cancel= true;
								DevExpress.ui.notify("Please select a region and countries", "error", 600);
							}							
							
							
						}
						
					});
				$(".dx-toolbar-after").hide();
					//buton
				$("#btsaverc").dxButton({
				type: "success",
				text: DevExpress.localization.formatMessage("Save and close"),
				onClick: function () {
				 $("#popuprc").dxPopup("hide");
				restartapp();
				
				}
				});
					
					
					
					
					
			}
			
		},
		error: function (data)
		{
				
				//$("#popuprc").append("<p>"+DevExpress.localization.formatMessage("Please wait...")+" </p>");
				//var poup = $("#popuprc").dxPopup({
				//		showTitle: true,
				//		title: "Loading...",
				//		visible: true,
				//		maxWidth: 600,
				//		maxHeight: 250,
				//		loseOnOutsideClick: true,
				//			onHidden: function (e) {
				//			location.reload();
				//			}					
				//	});
				setTimeout(reloadpage, 5000);
				return;
		}
	});

}
